@@ -12,12 +12,11 @@ from odf.text import P
 from pandas import (
     DataFrame,
     ExcelWriter,
+    Index,
     date_range,
     read_excel,
 )
 
-from ..pandas_vb_common import tm
-
 
 def _generate_dataframe():
     N = 2000
@@ -25,9 +24,9 @@ def _generate_dataframe():
     df = DataFrame(
         np.random.randn(N, C),
         columns=[f"float{i}" for i in range(C)],
-        index=date_range("20000101", periods=N, freq="H"),
+        index=date_range("20000101", periods=N, freq="h"),
     )
-    df["object"] = tm.makeStringIndex(N)
+    df["object"] = Index([f"i-{i}" for i in range(N)], dtype=object)
     return df
 
 
