@@ -18,20 +18,44 @@ import pandas._testing as tm
 from pandas.tests.frame.common import zip_frames
 
 
-def test_apply(float_frame):
+@pytest.fixture
+def int_frame_const_col():
+    """
+    Fixture for DataFrame of ints which are constant per column
+
+    Columns are ['A', 'B', 'C'], with values (per column): [1, 2, 3]
+    """
+    df = DataFrame(
+        np.tile(np.arange(3, dtype="int64"), 6).reshape(6, -1) + 1,
+        columns=["A", "B", "C"],
+    )
+    return df
+
+
+@pytest.fixture(params=["python", pytest.param("numba", marks=pytest.mark.single_cpu)])
+def engine(request):
+    if request.param == "numba":
+        pytest.importorskip("numba")
+    return request.param
+
+
+def test_apply(float_frame, engine, request):
+    if engine == "numba":
+        mark = pytest.mark.xfail(reason="numba engine not supporting numpy ufunc yet")
+        request.node.add_marker(mark)
     with np.errstate(all="ignore"):
         # ufunc
         result = np.sqrt(float_frame["A"])
-        expected = float_frame.apply(np.sqrt)["A"]
+        expected = float_frame.apply(np.sqrt, engine=engine)["A"]
         tm.assert_series_equal(result, expected)
 
         # aggregator
-        result = float_frame.apply(np.mean)["A"]
+        result = float_frame.apply(np.mean, engine=engine)["A"]
         expected = np.mean(float_frame["A"])
         assert result == expected
 
         d = float_frame.index[0]
-        result = float_frame.apply(np.mean, axis=1)
+        result = float_frame.apply(np.mean, axis=1, engine=engine)
         expected = np.mean(float_frame.xs(d))
         assert result[d] == expected
         assert result.index is float_frame.index
@@ -39,8 +63,13 @@ def test_apply(float_frame):
 
 @pytest.mark.parametrize("axis", [0, 1])
 @pytest.mark.parametrize("raw", [True, False])
-def test_apply_args(float_frame, axis, raw):
-    result = float_frame.apply(lambda x, y: x + y, axis, args=(1,), raw=raw)
+def test_apply_args(float_frame, axis, raw, engine, request):
+    if engine == "numba":
+        mark = pytest.mark.xfail(reason="numba engine doesn't support args")
+        request.node.add_marker(mark)
+    result = float_frame.apply(
+        lambda x, y: x + y, axis, args=(1,), raw=raw, engine=engine
+    )
     expected = float_frame + 1
     tm.assert_frame_equal(result, expected)
 
@@ -87,30 +116,30 @@ def test_apply_mixed_datetimelike():
 
 
 @pytest.mark.parametrize("func", [np.sqrt, np.mean])
-def test_apply_empty(func):
+def test_apply_empty(func, engine):
     # empty
     empty_frame = DataFrame()
 
-    result = empty_frame.apply(func)
+    result = empty_frame.apply(func, engine=engine)
     assert result.empty
 
 
-def test_apply_float_frame(float_frame):
+def test_apply_float_frame(float_frame, engine):
     no_rows = float_frame[:0]
-    result = no_rows.apply(lambda x: x.mean())
+    result = no_rows.apply(lambda x: x.mean(), engine=engine)
     expected = Series(np.nan, index=float_frame.columns)
     tm.assert_series_equal(result, expected)
 
     no_cols = float_frame.loc[:, []]
-    result = no_cols.apply(lambda x: x.mean(), axis=1)
+    result = no_cols.apply(lambda x: x.mean(), axis=1, engine=engine)
     expected = Series(np.nan, index=float_frame.index)
     tm.assert_series_equal(result, expected)
 
 
-def test_apply_empty_except_index():
+def test_apply_empty_except_index(engine):
     # GH 2476
     expected = DataFrame(index=["a"])
-    result = expected.apply(lambda x: x["a"], axis=1)
+    result = expected.apply(lambda x: x["a"], axis=1, engine=engine)
     tm.assert_frame_equal(result, expected)
 
 
@@ -235,36 +264,52 @@ def test_apply_broadcast_series_lambda_func(int_frame_const_col):
 
 
 @pytest.mark.parametrize("axis", [0, 1])
-def test_apply_raw_float_frame(float_frame, axis):
+def test_apply_raw_float_frame(float_frame, axis, engine):
+    if engine == "numba":
+        pytest.skip("numba can't handle when UDF returns None.")
+
     def _assert_raw(x):
         assert isinstance(x, np.ndarray)
         assert x.ndim == 1
 
-    float_frame.apply(_assert_raw, axis=axis, raw=True)
+    float_frame.apply(_assert_raw, axis=axis, engine=engine, raw=True)
 
 
 @pytest.mark.parametrize("axis", [0, 1])
-def test_apply_raw_float_frame_lambda(float_frame, axis):
-    result = float_frame.apply(np.mean, axis=axis, raw=True)
+def test_apply_raw_float_frame_lambda(float_frame, axis, engine):
+    result = float_frame.apply(np.mean, axis=axis, engine=engine, raw=True)
     expected = float_frame.apply(lambda x: x.values.mean(), axis=axis)
     tm.assert_series_equal(result, expected)
 
 
-def test_apply_raw_float_frame_no_reduction(float_frame):
+def test_apply_raw_float_frame_no_reduction(float_frame, engine):
     # no reduction
-    result = float_frame.apply(lambda x: x * 2, raw=True)
+    result = float_frame.apply(lambda x: x * 2, engine=engine, raw=True)
     expected = float_frame * 2
     tm.assert_frame_equal(result, expected)
 
 
 @pytest.mark.parametrize("axis", [0, 1])
-def test_apply_raw_mixed_type_frame(mixed_type_frame, axis):
+def test_apply_raw_mixed_type_frame(axis, engine):
+    if engine == "numba":
+        pytest.skip("isinstance check doesn't work with numba")
+
     def _assert_raw(x):
         assert isinstance(x, np.ndarray)
         assert x.ndim == 1
 
     # Mixed dtype (GH-32423)
-    mixed_type_frame.apply(_assert_raw, axis=axis, raw=True)
+    df = DataFrame(
+        {
+            "a": 1.0,
+            "b": 2,
+            "c": "foo",
+            "float32": np.array([1.0] * 10, dtype="float32"),
+            "int32": np.array([1] * 10, dtype="int32"),
+        },
+        index=np.arange(10),
+    )
+    df.apply(_assert_raw, axis=axis, engine=engine, raw=True)
 
 
 def test_apply_axis1(float_frame):
@@ -301,14 +346,14 @@ def test_apply_mixed_dtype_corner_indexing():
 )
 @pytest.mark.parametrize("raw", [True, False])
 @pytest.mark.parametrize("axis", [0, 1])
-def test_apply_empty_infer_type(ax, func, raw, axis):
+def test_apply_empty_infer_type(ax, func, raw, axis, engine, request):
     df = DataFrame(**{ax: ["a", "b", "c"]})
 
     with np.errstate(all="ignore"):
         test_res = func(np.array([], dtype="f8"))
         is_reduction = not isinstance(test_res, np.ndarray)
 
-        result = df.apply(func, axis=axis, raw=raw)
+        result = df.apply(func, axis=axis, engine=engine, raw=raw)
         if is_reduction:
             agg_axis = df._get_agg_axis(axis)
             assert isinstance(result, Series)
@@ -608,8 +653,10 @@ def test_apply_function_runs_once():
         assert names == list(df.index)
 
 
-def test_apply_raw_function_runs_once():
+def test_apply_raw_function_runs_once(engine):
     # https://github.com/pandas-dev/pandas/issues/34506
+    if engine == "numba":
+        pytest.skip("appending to list outside of numba func is not supported")
 
     df = DataFrame({"a": [1, 2, 3]})
     values = []  # Save row values function is applied to
@@ -624,7 +671,7 @@ def test_apply_raw_function_runs_once():
     for func in [reducing_function, non_reducing_function]:
         del values[:]
 
-        df.apply(func, raw=True, axis=1)
+        df.apply(func, engine=engine, raw=True, axis=1)
         assert values == list(df.a.to_list())
 
 
@@ -818,7 +865,7 @@ def test_with_listlike_columns():
         {
             "a": Series(np.random.default_rng(2).standard_normal(4)),
             "b": ["a", "list", "of", "words"],
-            "ts": date_range("2016-10-01", periods=4, freq="H"),
+            "ts": date_range("2016-10-01", periods=4, freq="h"),
         }
     )
 
@@ -960,45 +1007,69 @@ def test_result_type_shorter_list(int_frame_const_col):
     tm.assert_frame_equal(result, expected)
 
 
-def test_result_type_broadcast(int_frame_const_col):
+def test_result_type_broadcast(int_frame_const_col, request, engine):
     # result_type should be consistent no matter which
     # path we take in the code
+    if engine == "numba":
+        mark = pytest.mark.xfail(reason="numba engine doesn't support list return")
+        request.node.add_marker(mark)
     df = int_frame_const_col
     # broadcast result
-    result = df.apply(lambda x: [1, 2, 3], axis=1, result_type="broadcast")
-    expected = df.copy()
-    tm.assert_frame_equal(result, expected)
-
-
-def test_result_type_broadcast_series_func(int_frame_const_col):
-    # result_type should be consistent no matter which
-    # path we take in the code
-    df = int_frame_const_col
-    columns = ["other", "col", "names"]
     result = df.apply(
-        lambda x: Series([1, 2, 3], index=columns), axis=1, result_type="broadcast"
+        lambda x: [1, 2, 3], axis=1, result_type="broadcast", engine=engine
     )
     expected = df.copy()
     tm.assert_frame_equal(result, expected)
 
 
-def test_result_type_series_result(int_frame_const_col):
+def test_result_type_broadcast_series_func(int_frame_const_col, engine, request):
     # result_type should be consistent no matter which
     # path we take in the code
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="numba Series constructor only support ndarrays not list data"
+        )
+        request.node.add_marker(mark)
     df = int_frame_const_col
-    # series result
-    result = df.apply(lambda x: Series([1, 2, 3], index=x.index), axis=1)
+    columns = ["other", "col", "names"]
+    result = df.apply(
+        lambda x: Series([1, 2, 3], index=columns),
+        axis=1,
+        result_type="broadcast",
+        engine=engine,
+    )
     expected = df.copy()
     tm.assert_frame_equal(result, expected)
 
 
-def test_result_type_series_result_other_index(int_frame_const_col):
+def test_result_type_series_result(int_frame_const_col, engine, request):
     # result_type should be consistent no matter which
     # path we take in the code
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="numba Series constructor only support ndarrays not list data"
+        )
+        request.node.add_marker(mark)
+    df = int_frame_const_col
+    # series result
+    result = df.apply(lambda x: Series([1, 2, 3], index=x.index), axis=1, engine=engine)
+    expected = df.copy()
+    tm.assert_frame_equal(result, expected)
+
+
+def test_result_type_series_result_other_index(int_frame_const_col, engine, request):
+    # result_type should be consistent no matter which
+    # path we take in the code
+
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="no support in numba Series constructor for list of columns"
+        )
+        request.node.add_marker(mark)
     df = int_frame_const_col
     # series result with other index
     columns = ["other", "col", "names"]
-    result = df.apply(lambda x: Series([1, 2, 3], index=columns), axis=1)
+    result = df.apply(lambda x: Series([1, 2, 3], index=columns), axis=1, engine=engine)
     expected = df.copy()
     expected.columns = columns
     tm.assert_frame_equal(result, expected)
@@ -1232,7 +1303,7 @@ def test_nuiscance_columns():
 
     result = df.agg(["min"])
     expected = DataFrame(
-        [[1, 1.0, "bar", Timestamp("20130101")]],
+        [[1, 1.0, "bar", Timestamp("20130101").as_unit("ns")]],
         index=["min"],
         columns=df.columns,
     )
@@ -1358,25 +1429,34 @@ def test_agg_args_kwargs(axis, args, kwargs):
 
 
 @pytest.mark.parametrize("num_cols", [2, 3, 5])
-def test_frequency_is_original(num_cols):
+def test_frequency_is_original(num_cols, engine, request):
     # GH 22150
+    if engine == "numba":
+        mark = pytest.mark.xfail(reason="numba engine only supports numeric indices")
+        request.node.add_marker(mark)
     index = pd.DatetimeIndex(["1950-06-30", "1952-10-24", "1953-05-29"])
     original = index.copy()
     df = DataFrame(1, index=index, columns=range(num_cols))
-    df.apply(lambda x: x)
+    df.apply(lambda x: x, engine=engine)
     assert index.freq == original.freq
 
 
-def test_apply_datetime_tz_issue():
+def test_apply_datetime_tz_issue(engine, request):
     # GH 29052
 
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="numba engine doesn't support non-numeric indexes"
+        )
+        request.node.add_marker(mark)
+
     timestamps = [
         Timestamp("2019-03-15 12:34:31.909000+0000", tz="UTC"),
         Timestamp("2019-03-15 12:34:34.359000+0000", tz="UTC"),
         Timestamp("2019-03-15 12:34:34.660000+0000", tz="UTC"),
     ]
     df = DataFrame(data=[0, 1, 2], index=timestamps)
-    result = df.apply(lambda x: x.name, axis=1)
+    result = df.apply(lambda x: x.name, axis=1, engine=engine)
     expected = Series(index=timestamps, data=timestamps)
 
     tm.assert_series_equal(result, expected)
@@ -1384,13 +1464,16 @@ def test_apply_datetime_tz_issue():
 
 @pytest.mark.parametrize("df", [DataFrame({"A": ["a", None], "B": ["c", "d"]})])
 @pytest.mark.parametrize("method", ["min", "max", "sum"])
-def test_mixed_column_raises(df, method):
+def test_mixed_column_raises(df, method, using_infer_string):
     # GH 16832
     if method == "sum":
-        msg = r'can only concatenate str \(not "int"\) to str'
+        msg = r'can only concatenate str \(not "int"\) to str|does not support'
     else:
         msg = "not supported between instances of 'str' and 'float'"
-    with pytest.raises(TypeError, match=msg):
+    if not using_infer_string:
+        with pytest.raises(TypeError, match=msg):
+            getattr(df, method)()
+    else:
         getattr(df, method)()
 
 
@@ -1404,7 +1487,7 @@ def test_apply_dtype(col):
     tm.assert_series_equal(result, expected)
 
 
-def test_apply_mutating(using_array_manager, using_copy_on_write):
+def test_apply_mutating(using_array_manager, using_copy_on_write, warn_copy_on_write):
     # GH#35462 case where applied func pins a new BlockManager to a row
     df = DataFrame({"a": range(100), "b": range(100, 200)})
     df_orig = df.copy()
@@ -1418,7 +1501,8 @@ def test_apply_mutating(using_array_manager, using_copy_on_write):
     expected = df.copy()
     expected["a"] += 1
 
-    result = df.apply(func, axis=1)
+    with tm.assert_cow_warning(warn_copy_on_write):
+        result = df.apply(func, axis=1)
 
     tm.assert_frame_equal(result, expected)
     if using_copy_on_write or using_array_manager:
@@ -1439,10 +1523,15 @@ def test_apply_empty_list_reduce():
     tm.assert_series_equal(result, expected)
 
 
-def test_apply_no_suffix_index():
+def test_apply_no_suffix_index(engine, request):
     # GH36189
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="numba engine doesn't support list-likes/dict-like callables"
+        )
+        request.node.add_marker(mark)
     pdf = DataFrame([[4, 9]] * 3, columns=["A", "B"])
-    result = pdf.apply(["sum", lambda x: x.sum(), lambda x: x.sum()])
+    result = pdf.apply(["sum", lambda x: x.sum(), lambda x: x.sum()], engine=engine)
     expected = DataFrame(
         {"A": [12, 12, 12], "B": [27, 27, 27]}, index=["sum", "<lambda>", "<lambda>"]
     )
@@ -1450,10 +1539,12 @@ def test_apply_no_suffix_index():
     tm.assert_frame_equal(result, expected)
 
 
-def test_apply_raw_returns_string():
+def test_apply_raw_returns_string(engine):
     # https://github.com/pandas-dev/pandas/issues/35940
+    if engine == "numba":
+        pytest.skip("No object dtype support in numba")
     df = DataFrame({"A": ["aa", "bbb"]})
-    result = df.apply(lambda x: x[0], axis=1, raw=True)
+    result = df.apply(lambda x: x[0], engine=engine, axis=1, raw=True)
     expected = Series(["aa", "bbb"])
     tm.assert_series_equal(result, expected)
 
@@ -1489,10 +1580,17 @@ def test_aggregation_func_column_order():
     tm.assert_frame_equal(result, expected)
 
 
-def test_apply_getitem_axis_1():
+def test_apply_getitem_axis_1(engine, request):
     # GH 13427
+    if engine == "numba":
+        mark = pytest.mark.xfail(
+            reason="numba engine not supporting duplicate index values"
+        )
+        request.node.add_marker(mark)
     df = DataFrame({"a": [0, 1, 2], "b": [1, 2, 3]})
-    result = df[["a", "a"]].apply(lambda x: x.iloc[0] + x.iloc[1], axis=1)
+    result = df[["a", "a"]].apply(
+        lambda x: x.iloc[0] + x.iloc[1], axis=1, engine=engine
+    )
     expected = Series([0, 2, 4])
     tm.assert_series_equal(result, expected)
 
@@ -1532,10 +1630,10 @@ def test_apply_type():
     tm.assert_series_equal(result, expected)
 
 
-def test_apply_on_empty_dataframe():
+def test_apply_on_empty_dataframe(engine):
     # GH 39111
     df = DataFrame({"a": [1, 2], "b": [3, 0]})
-    result = df.head(0).apply(lambda x: max(x["a"], x["b"]), axis=1)
+    result = df.head(0).apply(lambda x: max(x["a"], x["b"]), axis=1, engine=engine)
     expected = Series([], dtype=np.float64)
     tm.assert_series_equal(result, expected)
 
