@@ -11,6 +11,8 @@ from pandas._libs import (
     OutOfBoundsDatetime,
     Timestamp,
 )
+from pandas._libs.tslibs.dtypes import freq_to_period_freqstr
+from pandas.compat.numpy import np_version_gt2
 
 import pandas as pd
 from pandas import (
@@ -26,12 +28,10 @@ from pandas.core.arrays import (
     PeriodArray,
     TimedeltaArray,
 )
-from pandas.core.arrays.datetimes import _sequence_to_dt64ns
-from pandas.core.arrays.timedeltas import sequence_to_td64ns
 
 
 # TODO: more freq variants
-@pytest.fixture(params=["D", "B", "W", "M", "Q", "Y"])
+@pytest.fixture(params=["D", "B", "W", "ME", "QE", "YE"])
 def freqstr(request):
     """Fixture returning parametrized frequency in string format."""
     return request.param
@@ -52,6 +52,7 @@ def period_index(freqstr):
         warnings.filterwarnings(
             "ignore", message="Period with BDay freq", category=FutureWarning
         )
+        freqstr = freq_to_period_freqstr(1, freqstr)
         pi = pd.period_range(start=Timestamp("2000-01-01"), periods=100, freq=freqstr)
     return pi
 
@@ -89,7 +90,10 @@ class SharedTests:
     def arr1d(self):
         """Fixture returning DatetimeArray with daily frequency."""
         data = np.arange(10, dtype="i8") * 24 * 3600 * 10**9
-        arr = self.array_cls(data, freq="D")
+        if self.array_cls is PeriodArray:
+            arr = self.array_cls(data, freq="D")
+        else:
+            arr = self.index_cls(data, freq="D")._data
         return arr
 
     def test_compare_len1_raises(self, arr1d):
@@ -161,7 +165,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = PeriodArray(data, dtype="period[D]")
         else:
-            arr = self.array_cls(data)
+            arr = self.index_cls(data)._data
         idx = self.index_cls._simple_new(arr)
 
         takers = [1, 4, 94]
@@ -183,9 +187,7 @@ class SharedTests:
             arr1d.take([0, 1], allow_fill=True, fill_value=fill_value)
 
     def test_take_fill(self, arr1d):
-        np.arange(10, dtype="i8") * 24 * 3600 * 10**9
-
-        arr = arr1d  # self.array_cls(data, freq="D")
+        arr = arr1d
 
         result = arr.take([-1, 1], allow_fill=True, fill_value=None)
         assert result[0] is NaT
@@ -213,11 +215,11 @@ class SharedTests:
         arr = arr1d
         idx = self.index_cls(arr)
         idx = idx.insert(0, NaT)
-        arr = self.array_cls(idx)
+        arr = arr1d
 
         result = arr._concat_same_type([arr[:-1], arr[1:], arr])
         arr2 = arr.astype(object)
-        expected = self.index_cls(np.concatenate([arr2[:-1], arr2[1:], arr2]), None)
+        expected = self.index_cls(np.concatenate([arr2[:-1], arr2[1:], arr2]))
 
         tm.assert_index_equal(self.index_cls(result), expected)
 
@@ -253,7 +255,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = self.array_cls(data, dtype="period[D]")
         else:
-            arr = self.array_cls(data)
+            arr = self.array_cls._from_sequence(data)
         arr[4] = NaT
 
         fill_value = arr[3] if method == "pad" else arr[5]
@@ -269,7 +271,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = self.array_cls(data, dtype="period[D]")
         else:
-            arr = self.array_cls(data)
+            arr = self.array_cls._from_sequence(data)
 
         # scalar
         result = arr.searchsorted(arr[1])
@@ -324,19 +326,12 @@ class SharedTests:
         ):
             arr.searchsorted("foo")
 
-        if string_storage == "python":
-            arr_type = "StringArray"
-        elif string_storage == "pyarrow":
-            arr_type = "ArrowStringArray"
-        else:
-            arr_type = "ArrowStringArrayNumpySemantics"
-
         with pd.option_context("string_storage", string_storage):
             with pytest.raises(
                 TypeError,
                 match=re.escape(
                     f"value should be a '{arr1d._scalar_type.__name__}', 'NaT', "
-                    f"or array of those. Got '{arr_type}' instead."
+                    "or array of those. Got string array instead."
                 ),
             ):
                 arr.searchsorted([str(arr[1]), "baz"])
@@ -348,7 +343,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = self.array_cls(i8vals, dtype="period[ns]")
         else:
-            arr = self.array_cls(i8vals, freq="ns")
+            arr = self.index_cls(i8vals, freq="ns")._data
         arr[0]  # should not raise OutOfBoundsDatetime
 
         index = pd.Index(arr)
@@ -359,13 +354,15 @@ class SharedTests:
 
     def test_getitem_2d(self, arr1d):
         # 2d slicing on a 1D array
-        expected = type(arr1d)(arr1d._ndarray[:, np.newaxis], dtype=arr1d.dtype)
+        expected = type(arr1d)._simple_new(
+            arr1d._ndarray[:, np.newaxis], dtype=arr1d.dtype
+        )
         result = arr1d[:, np.newaxis]
         tm.assert_equal(result, expected)
 
         # Lookup on a 2D array
         arr2d = expected
-        expected = type(arr2d)(arr2d._ndarray[:3, 0], dtype=arr2d.dtype)
+        expected = type(arr2d)._simple_new(arr2d._ndarray[:3, 0], dtype=arr2d.dtype)
         result = arr2d[:3, 0]
         tm.assert_equal(result, expected)
 
@@ -418,7 +415,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = self.array_cls(data, dtype="period[D]")
         else:
-            arr = self.array_cls(data, freq="D")
+            arr = self.index_cls(data, freq="D")._data
 
         arr[0] = arr[1]
         expected = np.arange(10, dtype="i8") * 24 * 3600 * 10**9
@@ -533,7 +530,7 @@ class SharedTests:
         if self.array_cls is PeriodArray:
             arr = self.array_cls(data, dtype="period[D]")
         else:
-            arr = self.array_cls(data, freq="D")
+            arr = self.index_cls(data, freq="D")._data
 
         expected = arr + pd.Timedelta(days=1)
         arr += pd.Timedelta(days=1)
@@ -598,10 +595,13 @@ class SharedTests:
 
     def test_from_integer_array(self):
         arr = np.array([1, 2, 3], dtype=np.int64)
-        expected = self.array_cls(arr, dtype=self.example_dtype)
-
         data = pd.array(arr, dtype="Int64")
-        result = self.array_cls(data, dtype=self.example_dtype)
+        if self.array_cls is PeriodArray:
+            expected = self.array_cls(arr, dtype=self.example_dtype)
+            result = self.array_cls(data, dtype=self.example_dtype)
+        else:
+            expected = self.array_cls._from_sequence(arr, dtype=self.example_dtype)
+            result = self.array_cls._from_sequence(data, dtype=self.example_dtype)
 
         tm.assert_extension_array_equal(result, expected)
 
@@ -627,25 +627,26 @@ class TestDatetimeArray(SharedTests):
         # GH#24064
         dti = self.index_cls(arr1d)
 
-        result = dti.round(freq="2T")
+        result = dti.round(freq="2min")
         expected = dti - pd.Timedelta(minutes=1)
         expected = expected._with_freq(None)
         tm.assert_index_equal(result, expected)
 
         dta = dti._data
-        result = dta.round(freq="2T")
+        result = dta.round(freq="2min")
         expected = expected._data._with_freq(None)
         tm.assert_datetime_array_equal(result, expected)
 
     def test_array_interface(self, datetime_index):
-        arr = DatetimeArray(datetime_index)
+        arr = datetime_index._data
+        copy_false = None if np_version_gt2 else False
 
         # default asarray gives the same underlying data (for tz naive)
         result = np.asarray(arr)
         expected = arr._ndarray
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
-        result = np.array(arr, copy=False)
+        result = np.array(arr, copy=copy_false)
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
 
@@ -654,11 +655,13 @@ class TestDatetimeArray(SharedTests):
         expected = arr._ndarray
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
-        result = np.array(arr, dtype="datetime64[ns]", copy=False)
+        result = np.array(arr, dtype="datetime64[ns]", copy=copy_false)
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
         result = np.array(arr, dtype="datetime64[ns]")
-        assert result is not expected
+        if not np_version_gt2:
+            # TODO: GH 57739
+            assert result is not expected
         tm.assert_numpy_array_equal(result, expected)
 
         # to object dtype
@@ -697,6 +700,7 @@ class TestDatetimeArray(SharedTests):
         # GH#23524
         arr = arr1d
         dti = self.index_cls(arr1d)
+        copy_false = None if np_version_gt2 else False
 
         expected = dti.asi8.view("M8[ns]")
         result = np.array(arr, dtype="M8[ns]")
@@ -705,17 +709,18 @@ class TestDatetimeArray(SharedTests):
         result = np.array(arr, dtype="datetime64[ns]")
         tm.assert_numpy_array_equal(result, expected)
 
-        # check that we are not making copies when setting copy=False
-        result = np.array(arr, dtype="M8[ns]", copy=False)
+        # check that we are not making copies when setting copy=copy_false
+        result = np.array(arr, dtype="M8[ns]", copy=copy_false)
         assert result.base is expected.base
         assert result.base is not None
-        result = np.array(arr, dtype="datetime64[ns]", copy=False)
+        result = np.array(arr, dtype="datetime64[ns]", copy=copy_false)
         assert result.base is expected.base
         assert result.base is not None
 
     def test_array_i8_dtype(self, arr1d):
         arr = arr1d
         dti = self.index_cls(arr1d)
+        copy_false = None if np_version_gt2 else False
 
         expected = dti.asi8
         result = np.array(arr, dtype="i8")
@@ -724,18 +729,18 @@ class TestDatetimeArray(SharedTests):
         result = np.array(arr, dtype=np.int64)
         tm.assert_numpy_array_equal(result, expected)
 
-        # check that we are still making copies when setting copy=False
-        result = np.array(arr, dtype="i8", copy=False)
+        # check that we are still making copies when setting copy=copy_false
+        result = np.array(arr, dtype="i8", copy=copy_false)
         assert result.base is not expected.base
         assert result.base is None
 
     def test_from_array_keeps_base(self):
         # Ensure that DatetimeArray._ndarray.base isn't lost.
         arr = np.array(["2000-01-01", "2000-01-02"], dtype="M8[ns]")
-        dta = DatetimeArray(arr)
+        dta = DatetimeArray._from_sequence(arr)
 
         assert dta._ndarray is arr
-        dta = DatetimeArray(arr[:0])
+        dta = DatetimeArray._from_sequence(arr[:0])
         assert dta._ndarray.base is arr
 
     def test_from_dti(self, arr1d):
@@ -760,8 +765,9 @@ class TestDatetimeArray(SharedTests):
     @pytest.mark.filterwarnings(r"ignore:PeriodDtype\[B\] is deprecated:FutureWarning")
     def test_to_period(self, datetime_index, freqstr):
         dti = datetime_index
-        arr = DatetimeArray(dti)
+        arr = dti._data
 
+        freqstr = freq_to_period_freqstr(1, freqstr)
         expected = dti.to_period(freq=freqstr)
         result = arr.to_period(freq=freqstr)
         assert isinstance(result, PeriodArray)
@@ -859,12 +865,12 @@ class TestDatetimeArray(SharedTests):
         with pytest.raises(ValueError, match="to_concat must have the same"):
             arr._concat_same_type([arr, other])
 
-    def test_concat_same_type_different_freq(self):
+    def test_concat_same_type_different_freq(self, unit):
         # we *can* concatenate DTI with different freqs.
-        a = DatetimeArray(pd.date_range("2000", periods=2, freq="D", tz="US/Central"))
-        b = DatetimeArray(pd.date_range("2000", periods=2, freq="H", tz="US/Central"))
+        a = pd.date_range("2000", periods=2, freq="D", tz="US/Central", unit=unit)._data
+        b = pd.date_range("2000", periods=2, freq="h", tz="US/Central", unit=unit)._data
         result = DatetimeArray._concat_same_type([a, b])
-        expected = DatetimeArray(
+        expected = (
             pd.to_datetime(
                 [
                     "2000-01-01 00:00:00",
@@ -872,7 +878,10 @@ class TestDatetimeArray(SharedTests):
                     "2000-01-01 00:00:00",
                     "2000-01-01 01:00:00",
                 ]
-            ).tz_localize("US/Central")
+            )
+            .tz_localize("US/Central")
+            .as_unit(unit)
+            ._data
         )
 
         tm.assert_datetime_array_equal(result, expected)
@@ -886,7 +895,7 @@ class TestDatetimeArray(SharedTests):
 
     def test_strftime_nat(self):
         # GH 29578
-        arr = DatetimeArray(DatetimeIndex(["2019-01-01", NaT]))
+        arr = DatetimeIndex(["2019-01-01", NaT])._data
 
         result = arr.strftime("%Y-%m-%d")
         expected = np.array(["2019-01-01", np.nan], dtype=object)
@@ -901,7 +910,7 @@ class TestTimedeltaArray(SharedTests):
 
     def test_from_tdi(self):
         tdi = TimedeltaIndex(["1 Day", "3 Hours"])
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
         assert list(arr) == list(tdi)
 
         # Check that Index.__new__ knows what to do with TimedeltaArray
@@ -911,7 +920,7 @@ class TestTimedeltaArray(SharedTests):
 
     def test_astype_object(self):
         tdi = TimedeltaIndex(["1 Day", "3 Hours"])
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
         asobj = arr.astype("O")
         assert isinstance(asobj, np.ndarray)
         assert asobj.dtype == "O"
@@ -919,7 +928,7 @@ class TestTimedeltaArray(SharedTests):
 
     def test_to_pytimedelta(self, timedelta_index):
         tdi = timedelta_index
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
 
         expected = tdi.to_pytimedelta()
         result = arr.to_pytimedelta()
@@ -928,7 +937,7 @@ class TestTimedeltaArray(SharedTests):
 
     def test_total_seconds(self, timedelta_index):
         tdi = timedelta_index
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
 
         expected = tdi.total_seconds()
         result = arr.total_seconds()
@@ -938,7 +947,7 @@ class TestTimedeltaArray(SharedTests):
     @pytest.mark.parametrize("propname", TimedeltaArray._field_ops)
     def test_int_properties(self, timedelta_index, propname):
         tdi = timedelta_index
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
 
         result = getattr(arr, propname)
         expected = np.array(getattr(tdi, propname), dtype=result.dtype)
@@ -946,14 +955,15 @@ class TestTimedeltaArray(SharedTests):
         tm.assert_numpy_array_equal(result, expected)
 
     def test_array_interface(self, timedelta_index):
-        arr = TimedeltaArray(timedelta_index)
+        arr = timedelta_index._data
+        copy_false = None if np_version_gt2 else False
 
         # default asarray gives the same underlying data
         result = np.asarray(arr)
         expected = arr._ndarray
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
-        result = np.array(arr, copy=False)
+        result = np.array(arr, copy=copy_false)
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
 
@@ -962,11 +972,13 @@ class TestTimedeltaArray(SharedTests):
         expected = arr._ndarray
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
-        result = np.array(arr, dtype="timedelta64[ns]", copy=False)
+        result = np.array(arr, dtype="timedelta64[ns]", copy=copy_false)
         assert result is expected
         tm.assert_numpy_array_equal(result, expected)
         result = np.array(arr, dtype="timedelta64[ns]")
-        assert result is not expected
+        if not np_version_gt2:
+            # TODO: GH 57739
+            assert result is not expected
         tm.assert_numpy_array_equal(result, expected)
 
         # to object dtype
@@ -989,7 +1001,7 @@ class TestTimedeltaArray(SharedTests):
 
     def test_take_fill_valid(self, timedelta_index, fixed_now_ts):
         tdi = timedelta_index
-        arr = TimedeltaArray(tdi)
+        arr = tdi._data
 
         td1 = pd.Timedelta(days=1)
         result = arr.take([-1, 1], allow_fill=True, fill_value=td1)
@@ -1064,7 +1076,7 @@ class TestPeriodArray(SharedTests):
         pi = self.index_cls(arr1d)
         arr = arr1d
 
-        expected = DatetimeArray(pi.to_timestamp(how=how))
+        expected = DatetimeIndex(pi.to_timestamp(how=how))._data
         result = arr.to_timestamp(how=how)
         assert isinstance(result, DatetimeArray)
 
@@ -1176,7 +1188,7 @@ class TestPeriodArray(SharedTests):
     ids=lambda x: type(x).__name__,
 )
 def test_casting_nat_setitem_array(arr, casting_nats):
-    expected = type(arr)._from_sequence([NaT, arr[1], arr[2]])
+    expected = type(arr)._from_sequence([NaT, arr[1], arr[2]], dtype=arr.dtype)
 
     for nat in casting_nats:
         arr = arr.copy()
@@ -1247,7 +1259,7 @@ def test_to_numpy_extra(arr):
     "values",
     [
         pd.to_datetime(["2020-01-01", "2020-02-01"]),
-        TimedeltaIndex([1, 2], unit="D"),
+        pd.to_timedelta([1, 2], unit="D"),
         PeriodIndex(["2020-01-01", "2020-02-01"], freq="D"),
     ],
 )
@@ -1278,7 +1290,7 @@ def test_searchsorted_datetimelike_with_listlike(values, klass, as_index):
     "values",
     [
         pd.to_datetime(["2020-01-01", "2020-02-01"]),
-        TimedeltaIndex([1, 2], unit="D"),
+        pd.to_timedelta([1, 2], unit="D"),
         PeriodIndex(["2020-01-01", "2020-02-01"], freq="D"),
     ],
 )
@@ -1310,19 +1322,16 @@ def test_from_pandas_array(dtype):
 
     cls = {"M8[ns]": DatetimeArray, "m8[ns]": TimedeltaArray}[dtype]
 
-    result = cls(arr)
-    expected = cls(data)
+    depr_msg = f"{cls.__name__}.__init__ is deprecated"
+    with tm.assert_produces_warning(FutureWarning, match=depr_msg):
+        result = cls(arr)
+        expected = cls(data)
     tm.assert_extension_array_equal(result, expected)
 
-    result = cls._from_sequence(arr)
-    expected = cls._from_sequence(data)
+    result = cls._from_sequence(arr, dtype=dtype)
+    expected = cls._from_sequence(data, dtype=dtype)
     tm.assert_extension_array_equal(result, expected)
 
-    func = {"M8[ns]": _sequence_to_dt64ns, "m8[ns]": sequence_to_td64ns}[dtype]
-    result = func(arr)[0]
-    expected = func(data)[0]
-    tm.assert_equal(result, expected)
-
     func = {"M8[ns]": pd.to_datetime, "m8[ns]": pd.to_timedelta}[dtype]
     result = func(arr).array
     expected = func(data).array
