@@ -77,7 +77,6 @@ class TestTake:
             idx.take(np.array([1, -5]))
 
     def test_take_fill_value_datetime(self):
-
         # datetime category
         idx = pd.DatetimeIndex(["2011-01-01", "2011-02-01", "2011-03-01"], name="xxx")
         idx = CategoricalIndex(idx)
@@ -219,15 +218,13 @@ class TestGetIndexer:
             idx.get_indexer(idx, method="invalid")
 
     def test_get_indexer_requires_unique(self):
-        np.random.seed(123456789)
-
         ci = CategoricalIndex(list("aabbca"), categories=list("cab"), ordered=False)
         oidx = Index(np.array(ci))
 
         msg = "Reindexing only valid with uniquely valued Index objects"
 
         for n in [1, 2, 5, len(ci)]:
-            finder = oidx[np.random.randint(0, len(ci), size=n)]
+            finder = oidx[np.random.default_rng(2).integers(0, len(ci), size=n)]
 
             with pytest.raises(InvalidIndexError, match=msg):
                 ci.get_indexer(finder)
@@ -239,12 +236,10 @@ class TestGetIndexer:
         # respect duplicates instead of taking
         # the fast-track path.
         for finder in [list("aabbca"), list("aababca")]:
-
             with pytest.raises(InvalidIndexError, match=msg):
                 ci.get_indexer(finder)
 
     def test_get_indexer_non_unique(self):
-
         idx1 = CategoricalIndex(list("aabcde"), categories=list("edabc"))
         idx2 = CategoricalIndex(list("abf"))
 
@@ -298,10 +293,23 @@ class TestGetIndexer:
         expected = np.array([1, 1], dtype="intp")
         tm.assert_numpy_array_equal(result, expected)
 
+    def test_get_indexer_nans_in_index_and_target(self):
+        # GH 45361
+        ci = CategoricalIndex([1, 2, np.nan, 3])
+        other1 = [2, 3, 4, np.nan]
+        res1 = ci.get_indexer(other1)
+        expected1 = np.array([1, 3, -1, 2], dtype=np.intp)
+        tm.assert_numpy_array_equal(res1, expected1)
+        other2 = [1, 4, 2, 3]
+        res2 = ci.get_indexer(other2)
+        expected2 = np.array([0, -1, 1, 3], dtype=np.intp)
+        tm.assert_numpy_array_equal(res2, expected2)
+
 
 class TestWhere:
-    @pytest.mark.parametrize("klass", [list, tuple, np.array, pd.Series])
-    def test_where(self, klass):
+    def test_where(self, listlike_box):
+        klass = listlike_box
+
         i = CategoricalIndex(list("aabbca"), categories=list("cab"), ordered=False)
         cond = [True] * len(i)
         expected = i
@@ -322,14 +330,13 @@ class TestWhere:
         tm.assert_index_equal(result, expected)
 
         msg = "Cannot setitem on a Categorical with a new category"
-        with pytest.raises(ValueError, match=msg):
+        with pytest.raises(TypeError, match=msg):
             # Test the Categorical method directly
-            ci._data.where(mask, 2)
+            ci._data._where(mask, 2)
 
 
 class TestContains:
     def test_contains(self):
-
         ci = CategoricalIndex(list("aabbca"), categories=list("cabdef"), ordered=False)
 
         assert "a" in ci
