@@ -17,8 +17,10 @@ from pandas.errors import (
 from pandas import (
     DataFrame,
     HDFStore,
+    Index,
     Series,
     _testing as tm,
+    date_range,
     read_hdf,
 )
 from pandas.tests.io.pytables.common import (
@@ -35,7 +37,11 @@ pytestmark = pytest.mark.single_cpu
 
 @pytest.mark.parametrize("mode", ["r", "r+", "a", "w"])
 def test_mode(setup_path, tmp_path, mode):
-    df = tm.makeTimeDataFrame()
+    df = DataFrame(
+        np.random.default_rng(2).standard_normal((10, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=date_range("2000-01-01", periods=10, freq="B"),
+    )
     msg = r"[\S]* does not exist"
     path = tmp_path / setup_path
 
@@ -64,10 +70,10 @@ def test_mode(setup_path, tmp_path, mode):
     # conv write
     if mode in ["r", "r+"]:
         with pytest.raises(OSError, match=msg):
-            df.to_hdf(path, "df", mode=mode)
-        df.to_hdf(path, "df", mode="w")
+            df.to_hdf(path, key="df", mode=mode)
+        df.to_hdf(path, key="df", mode="w")
     else:
-        df.to_hdf(path, "df", mode=mode)
+        df.to_hdf(path, key="df", mode=mode)
 
     # conv read
     if mode in ["w"]:
@@ -84,9 +90,13 @@ def test_mode(setup_path, tmp_path, mode):
 
 def test_default_mode(tmp_path, setup_path):
     # read_hdf uses default mode
-    df = tm.makeTimeDataFrame()
+    df = DataFrame(
+        np.random.default_rng(2).standard_normal((10, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=date_range("2000-01-01", periods=10, freq="B"),
+    )
     path = tmp_path / setup_path
-    df.to_hdf(path, "df", mode="w")
+    df.to_hdf(path, key="df", mode="w")
     result = read_hdf(path, "df")
     tm.assert_frame_equal(result, df)
 
@@ -95,7 +105,9 @@ def test_reopen_handle(tmp_path, setup_path):
     path = tmp_path / setup_path
 
     store = HDFStore(path, mode="a")
-    store["a"] = tm.makeTimeSeries()
+    store["a"] = Series(
+        np.arange(10, dtype=np.float64), index=date_range("2020-01-01", periods=10)
+    )
 
     msg = (
         r"Re-opening the file \[[\S]*\] with mode \[a\] will delete the "
@@ -116,7 +128,9 @@ def test_reopen_handle(tmp_path, setup_path):
     assert not store.is_open
 
     store = HDFStore(path, mode="a")
-    store["a"] = tm.makeTimeSeries()
+    store["a"] = Series(
+        np.arange(10, dtype=np.float64), index=date_range("2020-01-01", periods=10)
+    )
 
     # reopen as read
     store.open("r")
@@ -145,7 +159,11 @@ def test_reopen_handle(tmp_path, setup_path):
 
 def test_open_args(setup_path):
     with tm.ensure_clean(setup_path) as path:
-        df = tm.makeDataFrame()
+        df = DataFrame(
+            1.1 * np.arange(120).reshape((30, 4)),
+            columns=Index(list("ABCD"), dtype=object),
+            index=Index([f"i-{i}" for i in range(30)], dtype=object),
+        )
 
         # create an in memory store
         store = HDFStore(
@@ -165,19 +183,23 @@ def test_open_args(setup_path):
 
 def test_flush(setup_path):
     with ensure_clean_store(setup_path) as store:
-        store["a"] = tm.makeTimeSeries()
+        store["a"] = Series(range(5))
         store.flush()
         store.flush(fsync=True)
 
 
 def test_complibs_default_settings(tmp_path, setup_path):
     # GH15943
-    df = tm.makeDataFrame()
+    df = DataFrame(
+        1.1 * np.arange(120).reshape((30, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=Index([f"i-{i}" for i in range(30)], dtype=object),
+    )
 
     # Set complevel and check if complib is automatically set to
     # default value
     tmpfile = tmp_path / setup_path
-    df.to_hdf(tmpfile, "df", complevel=9)
+    df.to_hdf(tmpfile, key="df", complevel=9)
     result = read_hdf(tmpfile, "df")
     tm.assert_frame_equal(result, df)
 
@@ -188,7 +210,7 @@ def test_complibs_default_settings(tmp_path, setup_path):
 
     # Set complib and check to see if compression is disabled
     tmpfile = tmp_path / setup_path
-    df.to_hdf(tmpfile, "df", complib="zlib")
+    df.to_hdf(tmpfile, key="df", complib="zlib")
     result = read_hdf(tmpfile, "df")
     tm.assert_frame_equal(result, df)
 
@@ -199,7 +221,7 @@ def test_complibs_default_settings(tmp_path, setup_path):
 
     # Check if not setting complib or complevel results in no compression
     tmpfile = tmp_path / setup_path
-    df.to_hdf(tmpfile, "df")
+    df.to_hdf(tmpfile, key="df")
     result = read_hdf(tmpfile, "df")
     tm.assert_frame_equal(result, df)
 
@@ -211,7 +233,11 @@ def test_complibs_default_settings(tmp_path, setup_path):
 
 def test_complibs_default_settings_override(tmp_path, setup_path):
     # Check if file-defaults can be overridden on a per table basis
-    df = tm.makeDataFrame()
+    df = DataFrame(
+        1.1 * np.arange(120).reshape((30, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=Index([f"i-{i}" for i in range(30)], dtype=object),
+    )
     tmpfile = tmp_path / setup_path
     store = HDFStore(tmpfile)
     store.append("dfc", df, complevel=9, complib="blosc")
@@ -236,8 +262,12 @@ def test_complibs_default_settings_override(tmp_path, setup_path):
     # with xfail, would sometimes raise UnicodeDecodeError
     # invalid state byte
 )
-def test_complibs(tmp_path, lvl, lib):
+def test_complibs(tmp_path, lvl, lib, request):
     # GH14478
+    if PY311 and is_platform_linux() and lib == "blosc2" and lvl != 0:
+        request.applymarker(
+            pytest.mark.xfail(reason=f"Fails for {lib} on Linux and PY > 3.11")
+        )
     df = DataFrame(
         np.ones((30, 4)), columns=list("ABCD"), index=np.arange(30).astype(np.str_)
     )
@@ -253,7 +283,7 @@ def test_complibs(tmp_path, lvl, lib):
     gname = f"{lvl}_{lib}"
 
     # Write and read file to see if data is consistent
-    df.to_hdf(tmpfile, gname, complib=lib, complevel=lvl)
+    df.to_hdf(tmpfile, key=gname, complib=lib, complevel=lvl)
     result = read_hdf(tmpfile, gname)
     tm.assert_frame_equal(result, df)
 
@@ -308,10 +338,18 @@ def test_latin_encoding(tmp_path, setup_path, dtype, val):
     ser = Series(val, dtype=dtype)
 
     store = tmp_path / setup_path
-    ser.to_hdf(store, key, format="table", encoding=enc, nan_rep=nan_rep)
+    ser.to_hdf(store, key=key, format="table", encoding=enc, nan_rep=nan_rep)
     retr = read_hdf(store, key)
 
-    s_nan = ser.replace(nan_rep, np.nan)
+    # TODO:(3.0): once Categorical replace deprecation is enforced,
+    #  we may be able to re-simplify the construction of s_nan
+    if dtype == "category":
+        if nan_rep in ser.cat.categories:
+            s_nan = ser.cat.remove_categories([nan_rep])
+        else:
+            s_nan = ser
+    else:
+        s_nan = ser.replace(nan_rep, np.nan)
 
     tm.assert_series_equal(s_nan, retr)
 
@@ -321,8 +359,12 @@ def test_multiple_open_close(tmp_path, setup_path):
 
     path = tmp_path / setup_path
 
-    df = tm.makeDataFrame()
-    df.to_hdf(path, "df", mode="w", format="table")
+    df = DataFrame(
+        1.1 * np.arange(120).reshape((30, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=Index([f"i-{i}" for i in range(30)], dtype=object),
+    )
+    df.to_hdf(path, key="df", mode="w", format="table")
 
     # single
     store = HDFStore(path)
@@ -398,8 +440,12 @@ def test_multiple_open_close(tmp_path, setup_path):
     # ops on a closed store
     path = tmp_path / setup_path
 
-    df = tm.makeDataFrame()
-    df.to_hdf(path, "df", mode="w", format="table")
+    df = DataFrame(
+        1.1 * np.arange(120).reshape((30, 4)),
+        columns=Index(list("ABCD"), dtype=object),
+        index=Index([f"i-{i}" for i in range(30)], dtype=object),
+    )
+    df.to_hdf(path, key="df", mode="w", format="table")
 
     store = HDFStore(path)
     store.close()
