@@ -1,57 +1,44 @@
 """ Test cases for DataFrame.plot """
 import re
-import warnings
 
 import numpy as np
 import pytest
 
-import pandas.util._test_decorators as td
-
 import pandas as pd
 from pandas import DataFrame
 import pandas._testing as tm
 from pandas.tests.plotting.common import (
-    TestPlotBase,
+    _check_colors,
     _check_plot_works,
+    _unpack_cycler,
 )
+from pandas.util.version import Version
 
-pytestmark = pytest.mark.slow
+mpl = pytest.importorskip("matplotlib")
+plt = pytest.importorskip("matplotlib.pyplot")
+cm = pytest.importorskip("matplotlib.cm")
 
 
-@td.skip_if_no_mpl
-class TestDataFrameColor(TestPlotBase):
-    def setup_method(self, method):
-        TestPlotBase.setup_method(self, method)
-        import matplotlib as mpl
+def _check_colors_box(bp, box_c, whiskers_c, medians_c, caps_c="k", fliers_c=None):
+    if fliers_c is None:
+        fliers_c = "k"
+    _check_colors(bp["boxes"], linecolors=[box_c] * len(bp["boxes"]))
+    _check_colors(bp["whiskers"], linecolors=[whiskers_c] * len(bp["whiskers"]))
+    _check_colors(bp["medians"], linecolors=[medians_c] * len(bp["medians"]))
+    _check_colors(bp["fliers"], linecolors=[fliers_c] * len(bp["fliers"]))
+    _check_colors(bp["caps"], linecolors=[caps_c] * len(bp["caps"]))
 
-        mpl.rcdefaults()
 
-        self.tdf = tm.makeTimeDataFrame()
-        self.hexbin_df = DataFrame(
-            {
-                "A": np.random.uniform(size=20),
-                "B": np.random.uniform(size=20),
-                "C": np.arange(20) + np.random.uniform(size=20),
-            }
-        )
-
-    def test_mpl2_color_cycle_str(self):
+class TestDataFrameColor:
+    @pytest.mark.parametrize(
+        "color", ["C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9"]
+    )
+    def test_mpl2_color_cycle_str(self, color):
         # GH 15516
-        df = DataFrame(np.random.randn(10, 3), columns=["a", "b", "c"])
-        colors = ["C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9"]
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always", "MatplotlibDeprecationWarning")
-
-            for color in colors:
-                _check_plot_works(df.plot, color=color)
-
-            # if warning is raised, check that it is the exact problematic one
-            # GH 36972
-            if w:
-                match = "Support for uppercase single-letter colors is deprecated"
-                warning_message = str(w[0].message)
-                msg = "MatplotlibDeprecationWarning related to CN colors was raised"
-                assert match not in warning_message, msg
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 3)), columns=["a", "b", "c"]
+        )
+        _check_plot_works(df.plot, color=color)
 
     def test_color_single_series_list(self):
         # GH 3486
@@ -65,7 +52,7 @@ class TestDataFrameColor(TestPlotBase):
         _check_plot_works(df.plot, x="x", y="y", color=color)
 
     def test_color_empty_string(self):
-        df = DataFrame(np.random.randn(10, 2))
+        df = DataFrame(np.random.default_rng(2).standard_normal((10, 2)))
         with pytest.raises(ValueError, match="Invalid color argument:"):
             df.plot(color="")
 
@@ -99,7 +86,7 @@ class TestDataFrameColor(TestPlotBase):
     )
     def test_color_and_marker(self, color, expected):
         # GH 21003
-        df = DataFrame(np.random.random((7, 4)))
+        df = DataFrame(np.random.default_rng(2).random((7, 4)))
         ax = df.plot(color=color, style="d--")
         # check colors
         result = [i.get_color() for i in ax.lines]
@@ -109,41 +96,35 @@ class TestDataFrameColor(TestPlotBase):
         assert all(i.get_marker() == "d" for i in ax.lines)
 
     def test_bar_colors(self):
-        import matplotlib.pyplot as plt
+        default_colors = _unpack_cycler(plt.rcParams)
 
-        default_colors = self._unpack_cycler(plt.rcParams)
-
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot.bar()
-        self._check_colors(ax.patches[::5], facecolors=default_colors[:5])
-        tm.close()
+        _check_colors(ax.patches[::5], facecolors=default_colors[:5])
 
+    def test_bar_colors_custom(self):
         custom_colors = "rgcby"
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot.bar(color=custom_colors)
-        self._check_colors(ax.patches[::5], facecolors=custom_colors)
-        tm.close()
+        _check_colors(ax.patches[::5], facecolors=custom_colors)
 
-        from matplotlib import cm
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_bar_colors_cmap(self, colormap):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
 
-        # Test str -> colormap functionality
-        ax = df.plot.bar(colormap="jet")
+        ax = df.plot.bar(colormap=colormap)
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, 5)]
-        self._check_colors(ax.patches[::5], facecolors=rgba_colors)
-        tm.close()
-
-        # Test colormap functionality
-        ax = df.plot.bar(colormap=cm.jet)
-        rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, 5)]
-        self._check_colors(ax.patches[::5], facecolors=rgba_colors)
-        tm.close()
+        _check_colors(ax.patches[::5], facecolors=rgba_colors)
 
+    def test_bar_colors_single_col(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.loc[:, [0]].plot.bar(color="DodgerBlue")
-        self._check_colors([ax.patches[0]], facecolors=["DodgerBlue"])
-        tm.close()
+        _check_colors([ax.patches[0]], facecolors=["DodgerBlue"])
 
+    def test_bar_colors_green(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot(kind="bar", color="green")
-        self._check_colors(ax.patches[::5], facecolors=["green"] * 5)
-        tm.close()
+        _check_colors(ax.patches[::5], facecolors=["green"] * 5)
 
     def test_bar_user_colors(self):
         df = DataFrame(
@@ -165,7 +146,7 @@ class TestDataFrameColor(TestPlotBase):
         # addressing issue #10611, to ensure colobar does not
         # interfere with x-axis label and ticklabels with
         # ipython inline backend.
-        random_array = np.random.random((1000, 3))
+        random_array = np.random.default_rng(2).random((10, 3))
         df = DataFrame(random_array, columns=["A label", "B label", "C label"])
 
         ax1 = df.plot.scatter(x="A label", y="B label")
@@ -187,7 +168,7 @@ class TestDataFrameColor(TestPlotBase):
         # addressing issue #10678, to ensure colobar does not
         # interfere with x-axis label and ticklabels with
         # ipython inline backend.
-        random_array = np.random.random((1000, 3))
+        random_array = np.random.default_rng(2).random((10, 3))
         df = DataFrame(random_array, columns=["A label", "B label", "C label"])
 
         ax = df.plot.hexbin("A label", "B label", gridsize=12)
@@ -196,9 +177,7 @@ class TestDataFrameColor(TestPlotBase):
         assert ax.xaxis.get_label().get_visible()
 
     def test_if_scatterplot_colorbars_are_next_to_parent_axes(self):
-        import matplotlib.pyplot as plt
-
-        random_array = np.random.random((1000, 3))
+        random_array = np.random.default_rng(2).random((10, 3))
         df = DataFrame(random_array, columns=["A label", "B label", "C label"])
 
         fig, axes = plt.subplots(1, 2)
@@ -215,12 +194,17 @@ class TestDataFrameColor(TestPlotBase):
     @pytest.mark.parametrize("cmap", [None, "Greys"])
     def test_scatter_with_c_column_name_with_colors(self, cmap):
         # https://github.com/pandas-dev/pandas/issues/34316
+
         df = DataFrame(
             [[5.1, 3.5], [4.9, 3.0], [7.0, 3.2], [6.4, 3.2], [5.9, 3.0]],
             columns=["length", "width"],
         )
         df["species"] = ["r", "r", "g", "g", "b"]
-        ax = df.plot.scatter(x=0, y=1, c="species", cmap=cmap)
+        if cmap is not None:
+            with tm.assert_produces_warning(UserWarning, check_stacklevel=False):
+                ax = df.plot.scatter(x=0, y=1, cmap=cmap, c="species")
+        else:
+            ax = df.plot.scatter(x=0, y=1, c="species", cmap=cmap)
         assert ax.collections[0].colorbar is None
 
     def test_scatter_colors(self):
@@ -228,14 +212,25 @@ class TestDataFrameColor(TestPlotBase):
         with pytest.raises(TypeError, match="Specify exactly one of `c` and `color`"):
             df.plot.scatter(x="a", y="b", c="c", color="green")
 
-        default_colors = self._unpack_cycler(self.plt.rcParams)
+    def test_scatter_colors_not_raising_warnings(self):
+        # GH-53908. Do not raise UserWarning: No data for colormapping
+        # provided via 'c'. Parameters 'cmap' will be ignored
+        df = DataFrame({"x": [1, 2, 3], "y": [1, 2, 3]})
+        with tm.assert_produces_warning(None):
+            df.plot.scatter(x="x", y="y", c="b")
+
+    def test_scatter_colors_default(self):
+        df = DataFrame({"a": [1, 2, 3], "b": [1, 2, 3], "c": [1, 2, 3]})
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
 
         ax = df.plot.scatter(x="a", y="b", c="c")
         tm.assert_numpy_array_equal(
             ax.collections[0].get_facecolor()[0],
-            np.array(self.colorconverter.to_rgba(default_colors[0])),
+            np.array(mpl.colors.ColorConverter.to_rgba(default_colors[0])),
         )
 
+    def test_scatter_colors_white(self):
+        df = DataFrame({"a": [1, 2, 3], "b": [1, 2, 3], "c": [1, 2, 3]})
         ax = df.plot.scatter(x="a", y="b", color="white")
         tm.assert_numpy_array_equal(
             ax.collections[0].get_facecolor()[0],
@@ -244,12 +239,10 @@ class TestDataFrameColor(TestPlotBase):
 
     def test_scatter_colorbar_different_cmap(self):
         # GH 33389
-        import matplotlib.pyplot as plt
-
         df = DataFrame({"x": [1, 2, 3], "y": [1, 3, 2], "c": [1, 2, 3]})
         df["x2"] = df["x"] + 1
 
-        fig, ax = plt.subplots()
+        _, ax = plt.subplots()
         df.plot("x", "y", c="c", kind="scatter", cmap="cividis", ax=ax)
         df.plot("x2", "y", c="c", kind="scatter", cmap="magma", ax=ax)
 
@@ -257,15 +250,13 @@ class TestDataFrameColor(TestPlotBase):
         assert ax.collections[1].cmap.name == "magma"
 
     def test_line_colors(self):
-        from matplotlib import cm
-
         custom_colors = "rgcby"
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
 
         ax = df.plot(color=custom_colors)
-        self._check_colors(ax.get_lines(), linecolors=custom_colors)
+        _check_colors(ax.get_lines(), linecolors=custom_colors)
 
-        tm.close()
+        plt.close("all")
 
         ax2 = df.plot(color=custom_colors)
         lines2 = ax2.get_lines()
@@ -273,288 +264,279 @@ class TestDataFrameColor(TestPlotBase):
         for l1, l2 in zip(ax.get_lines(), lines2):
             assert l1.get_color() == l2.get_color()
 
-        tm.close()
-
-        ax = df.plot(colormap="jet")
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_line_colors_cmap(self, colormap):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        ax = df.plot(colormap=colormap)
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        self._check_colors(ax.get_lines(), linecolors=rgba_colors)
-        tm.close()
-
-        ax = df.plot(colormap=cm.jet)
-        rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        self._check_colors(ax.get_lines(), linecolors=rgba_colors)
-        tm.close()
+        _check_colors(ax.get_lines(), linecolors=rgba_colors)
 
+    def test_line_colors_single_col(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # make color a list if plotting one column frame
         # handles cases like df.plot(color='DodgerBlue')
         ax = df.loc[:, [0]].plot(color="DodgerBlue")
-        self._check_colors(ax.lines, linecolors=["DodgerBlue"])
+        _check_colors(ax.lines, linecolors=["DodgerBlue"])
 
+    def test_line_colors_single_color(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot(color="red")
-        self._check_colors(ax.get_lines(), linecolors=["red"] * 5)
-        tm.close()
+        _check_colors(ax.get_lines(), linecolors=["red"] * 5)
 
+    def test_line_colors_hex(self):
         # GH 10299
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         custom_colors = ["#FF0000", "#0000FF", "#FFFF00", "#000000", "#FFFFFF"]
         ax = df.plot(color=custom_colors)
-        self._check_colors(ax.get_lines(), linecolors=custom_colors)
-        tm.close()
+        _check_colors(ax.get_lines(), linecolors=custom_colors)
 
     def test_dont_modify_colors(self):
         colors = ["r", "g", "b"]
-        DataFrame(np.random.rand(10, 2)).plot(color=colors)
+        DataFrame(np.random.default_rng(2).random((10, 2))).plot(color=colors)
         assert len(colors) == 3
 
     def test_line_colors_and_styles_subplots(self):
         # GH 9894
-        from matplotlib import cm
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
 
-        default_colors = self._unpack_cycler(self.plt.rcParams)
-
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
 
         axes = df.plot(subplots=True)
         for ax, c in zip(axes, list(default_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
-        # single color char
-        axes = df.plot(subplots=True, color="k")
+    @pytest.mark.parametrize("color", ["k", "green"])
+    def test_line_colors_and_styles_subplots_single_color_str(self, color):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        axes = df.plot(subplots=True, color=color)
         for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["k"])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[color])
 
-        # single color str
-        axes = df.plot(subplots=True, color="green")
-        for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["green"])
-        tm.close()
-
-        custom_colors = "rgcby"
-        axes = df.plot(color=custom_colors, subplots=True)
-        for ax, c in zip(axes, list(custom_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
-
-        axes = df.plot(color=list(custom_colors), subplots=True)
-        for ax, c in zip(axes, list(custom_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+    @pytest.mark.parametrize("color", ["rgcby", list("rgcby")])
+    def test_line_colors_and_styles_subplots_custom_colors(self, color):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        axes = df.plot(color=color, subplots=True)
+        for ax, c in zip(axes, list(color)):
+            _check_colors(ax.get_lines(), linecolors=[c])
 
+    def test_line_colors_and_styles_subplots_colormap_hex(self):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # GH 10299
         custom_colors = ["#FF0000", "#0000FF", "#FFFF00", "#000000", "#FFFFFF"]
         axes = df.plot(color=custom_colors, subplots=True)
         for ax, c in zip(axes, list(custom_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
+    @pytest.mark.parametrize("cmap", ["jet", cm.jet])
+    def test_line_colors_and_styles_subplots_colormap_subplot(self, cmap):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        for cmap in ["jet", cm.jet]:
-            axes = df.plot(colormap=cmap, subplots=True)
-            for ax, c in zip(axes, rgba_colors):
-                self._check_colors(ax.get_lines(), linecolors=[c])
-            tm.close()
+        axes = df.plot(colormap=cmap, subplots=True)
+        for ax, c in zip(axes, rgba_colors):
+            _check_colors(ax.get_lines(), linecolors=[c])
 
+    def test_line_colors_and_styles_subplots_single_col(self):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # make color a list if plotting one column frame
         # handles cases like df.plot(color='DodgerBlue')
         axes = df.loc[:, [0]].plot(color="DodgerBlue", subplots=True)
-        self._check_colors(axes[0].lines, linecolors=["DodgerBlue"])
+        _check_colors(axes[0].lines, linecolors=["DodgerBlue"])
 
+    def test_line_colors_and_styles_subplots_single_char(self):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # single character style
         axes = df.plot(style="r", subplots=True)
         for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["r"])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=["r"])
 
+    def test_line_colors_and_styles_subplots_list_styles(self):
+        # GH 9894
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # list of styles
         styles = list("rgcby")
         axes = df.plot(style=styles, subplots=True)
         for ax, c in zip(axes, styles):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
     def test_area_colors(self):
-        from matplotlib import cm
         from matplotlib.collections import PolyCollection
 
         custom_colors = "rgcby"
-        df = DataFrame(np.random.rand(5, 5))
+        df = DataFrame(np.random.default_rng(2).random((5, 5)))
 
         ax = df.plot.area(color=custom_colors)
-        self._check_colors(ax.get_lines(), linecolors=custom_colors)
+        _check_colors(ax.get_lines(), linecolors=custom_colors)
         poly = [o for o in ax.get_children() if isinstance(o, PolyCollection)]
-        self._check_colors(poly, facecolors=custom_colors)
+        _check_colors(poly, facecolors=custom_colors)
 
-        handles, labels = ax.get_legend_handles_labels()
-        self._check_colors(handles, facecolors=custom_colors)
+        handles, _ = ax.get_legend_handles_labels()
+        _check_colors(handles, facecolors=custom_colors)
 
         for h in handles:
             assert h.get_alpha() is None
-        tm.close()
 
+    def test_area_colors_poly(self):
+        from matplotlib import cm
+        from matplotlib.collections import PolyCollection
+
+        df = DataFrame(np.random.default_rng(2).random((5, 5)))
         ax = df.plot.area(colormap="jet")
         jet_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        self._check_colors(ax.get_lines(), linecolors=jet_colors)
+        _check_colors(ax.get_lines(), linecolors=jet_colors)
         poly = [o for o in ax.get_children() if isinstance(o, PolyCollection)]
-        self._check_colors(poly, facecolors=jet_colors)
+        _check_colors(poly, facecolors=jet_colors)
 
-        handles, labels = ax.get_legend_handles_labels()
-        self._check_colors(handles, facecolors=jet_colors)
+        handles, _ = ax.get_legend_handles_labels()
+        _check_colors(handles, facecolors=jet_colors)
         for h in handles:
             assert h.get_alpha() is None
-        tm.close()
 
+    def test_area_colors_stacked_false(self):
+        from matplotlib import cm
+        from matplotlib.collections import PolyCollection
+
+        df = DataFrame(np.random.default_rng(2).random((5, 5)))
+        jet_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
         # When stacked=False, alpha is set to 0.5
         ax = df.plot.area(colormap=cm.jet, stacked=False)
-        self._check_colors(ax.get_lines(), linecolors=jet_colors)
+        _check_colors(ax.get_lines(), linecolors=jet_colors)
         poly = [o for o in ax.get_children() if isinstance(o, PolyCollection)]
         jet_with_alpha = [(c[0], c[1], c[2], 0.5) for c in jet_colors]
-        self._check_colors(poly, facecolors=jet_with_alpha)
+        _check_colors(poly, facecolors=jet_with_alpha)
 
-        handles, labels = ax.get_legend_handles_labels()
+        handles, _ = ax.get_legend_handles_labels()
         linecolors = jet_with_alpha
-        self._check_colors(handles[: len(jet_colors)], linecolors=linecolors)
+        _check_colors(handles[: len(jet_colors)], linecolors=linecolors)
         for h in handles:
             assert h.get_alpha() == 0.5
 
     def test_hist_colors(self):
-        default_colors = self._unpack_cycler(self.plt.rcParams)
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
 
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot.hist()
-        self._check_colors(ax.patches[::10], facecolors=default_colors[:5])
-        tm.close()
+        _check_colors(ax.patches[::10], facecolors=default_colors[:5])
 
+    def test_hist_colors_single_custom(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         custom_colors = "rgcby"
         ax = df.plot.hist(color=custom_colors)
-        self._check_colors(ax.patches[::10], facecolors=custom_colors)
-        tm.close()
+        _check_colors(ax.patches[::10], facecolors=custom_colors)
 
-        from matplotlib import cm
-
-        # Test str -> colormap functionality
-        ax = df.plot.hist(colormap="jet")
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_hist_colors_cmap(self, colormap):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        ax = df.plot.hist(colormap=colormap)
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, 5)]
-        self._check_colors(ax.patches[::10], facecolors=rgba_colors)
-        tm.close()
-
-        # Test colormap functionality
-        ax = df.plot.hist(colormap=cm.jet)
-        rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, 5)]
-        self._check_colors(ax.patches[::10], facecolors=rgba_colors)
-        tm.close()
+        _check_colors(ax.patches[::10], facecolors=rgba_colors)
 
+    def test_hist_colors_single_col(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.loc[:, [0]].plot.hist(color="DodgerBlue")
-        self._check_colors([ax.patches[0]], facecolors=["DodgerBlue"])
+        _check_colors([ax.patches[0]], facecolors=["DodgerBlue"])
 
+    def test_hist_colors_single_color(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         ax = df.plot(kind="hist", color="green")
-        self._check_colors(ax.patches[::10], facecolors=["green"] * 5)
-        tm.close()
+        _check_colors(ax.patches[::10], facecolors=["green"] * 5)
 
-    @td.skip_if_no_scipy
     def test_kde_colors(self):
-        from matplotlib import cm
-
+        pytest.importorskip("scipy")
         custom_colors = "rgcby"
-        df = DataFrame(np.random.rand(5, 5))
+        df = DataFrame(np.random.default_rng(2).random((5, 5)))
 
         ax = df.plot.kde(color=custom_colors)
-        self._check_colors(ax.get_lines(), linecolors=custom_colors)
-        tm.close()
+        _check_colors(ax.get_lines(), linecolors=custom_colors)
 
-        ax = df.plot.kde(colormap="jet")
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_kde_colors_cmap(self, colormap):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        ax = df.plot.kde(colormap=colormap)
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        self._check_colors(ax.get_lines(), linecolors=rgba_colors)
-        tm.close()
+        _check_colors(ax.get_lines(), linecolors=rgba_colors)
 
-        ax = df.plot.kde(colormap=cm.jet)
-        rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        self._check_colors(ax.get_lines(), linecolors=rgba_colors)
-
-    @td.skip_if_no_scipy
     def test_kde_colors_and_styles_subplots(self):
-        from matplotlib import cm
+        pytest.importorskip("scipy")
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
 
-        default_colors = self._unpack_cycler(self.plt.rcParams)
-
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
 
         axes = df.plot(kind="kde", subplots=True)
         for ax, c in zip(axes, list(default_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
-        # single color char
-        axes = df.plot(kind="kde", color="k", subplots=True)
+    @pytest.mark.parametrize("colormap", ["k", "red"])
+    def test_kde_colors_and_styles_subplots_single_col_str(self, colormap):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        axes = df.plot(kind="kde", color=colormap, subplots=True)
         for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["k"])
-        tm.close()
-
-        # single color str
-        axes = df.plot(kind="kde", color="red", subplots=True)
-        for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["red"])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[colormap])
 
+    def test_kde_colors_and_styles_subplots_custom_color(self):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         custom_colors = "rgcby"
         axes = df.plot(kind="kde", color=custom_colors, subplots=True)
         for ax, c in zip(axes, list(custom_colors)):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_kde_colors_and_styles_subplots_cmap(self, colormap):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         rgba_colors = [cm.jet(n) for n in np.linspace(0, 1, len(df))]
-        for cmap in ["jet", cm.jet]:
-            axes = df.plot(kind="kde", colormap=cmap, subplots=True)
-            for ax, c in zip(axes, rgba_colors):
-                self._check_colors(ax.get_lines(), linecolors=[c])
-            tm.close()
+        axes = df.plot(kind="kde", colormap=colormap, subplots=True)
+        for ax, c in zip(axes, rgba_colors):
+            _check_colors(ax.get_lines(), linecolors=[c])
 
+    def test_kde_colors_and_styles_subplots_single_col(self):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # make color a list if plotting one column frame
         # handles cases like df.plot(color='DodgerBlue')
         axes = df.loc[:, [0]].plot(kind="kde", color="DodgerBlue", subplots=True)
-        self._check_colors(axes[0].lines, linecolors=["DodgerBlue"])
+        _check_colors(axes[0].lines, linecolors=["DodgerBlue"])
 
+    def test_kde_colors_and_styles_subplots_single_char(self):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        # list of styles
         # single character style
         axes = df.plot(kind="kde", style="r", subplots=True)
         for ax in axes:
-            self._check_colors(ax.get_lines(), linecolors=["r"])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=["r"])
 
+    def test_kde_colors_and_styles_subplots_list(self):
+        pytest.importorskip("scipy")
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # list of styles
         styles = list("rgcby")
         axes = df.plot(kind="kde", style=styles, subplots=True)
         for ax, c in zip(axes, styles):
-            self._check_colors(ax.get_lines(), linecolors=[c])
-        tm.close()
+            _check_colors(ax.get_lines(), linecolors=[c])
 
     def test_boxplot_colors(self):
-        def _check_colors(bp, box_c, whiskers_c, medians_c, caps_c="k", fliers_c=None):
-            # TODO: outside this func?
-            if fliers_c is None:
-                fliers_c = "k"
-            self._check_colors(bp["boxes"], linecolors=[box_c] * len(bp["boxes"]))
-            self._check_colors(
-                bp["whiskers"], linecolors=[whiskers_c] * len(bp["whiskers"])
-            )
-            self._check_colors(
-                bp["medians"], linecolors=[medians_c] * len(bp["medians"])
-            )
-            self._check_colors(bp["fliers"], linecolors=[fliers_c] * len(bp["fliers"]))
-            self._check_colors(bp["caps"], linecolors=[caps_c] * len(bp["caps"]))
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
 
-        default_colors = self._unpack_cycler(self.plt.rcParams)
-
-        df = DataFrame(np.random.randn(5, 5))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         bp = df.plot.box(return_type="dict")
-        _check_colors(
+        _check_colors_box(
             bp,
             default_colors[0],
             default_colors[0],
             default_colors[2],
             default_colors[0],
         )
-        tm.close()
 
+    def test_boxplot_colors_dict_colors(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         dict_colors = {
             "boxes": "#572923",
             "whiskers": "#982042",
@@ -562,7 +544,7 @@ class TestDataFrameColor(TestPlotBase):
             "caps": "#123456",
         }
         bp = df.plot.box(color=dict_colors, sym="r+", return_type="dict")
-        _check_colors(
+        _check_colors_box(
             bp,
             dict_colors["boxes"],
             dict_colors["whiskers"],
@@ -570,35 +552,38 @@ class TestDataFrameColor(TestPlotBase):
             dict_colors["caps"],
             "r",
         )
-        tm.close()
 
+    def test_boxplot_colors_default_color(self):
+        default_colors = _unpack_cycler(mpl.pyplot.rcParams)
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # partial colors
         dict_colors = {"whiskers": "c", "medians": "m"}
         bp = df.plot.box(color=dict_colors, return_type="dict")
-        _check_colors(bp, default_colors[0], "c", "m", default_colors[0])
-        tm.close()
+        _check_colors_box(bp, default_colors[0], "c", "m", default_colors[0])
 
-        from matplotlib import cm
-
-        # Test str -> colormap functionality
-        bp = df.plot.box(colormap="jet", return_type="dict")
+    @pytest.mark.parametrize("colormap", ["jet", cm.jet])
+    def test_boxplot_colors_cmap(self, colormap):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
+        bp = df.plot.box(colormap=colormap, return_type="dict")
         jet_colors = [cm.jet(n) for n in np.linspace(0, 1, 3)]
-        _check_colors(bp, jet_colors[0], jet_colors[0], jet_colors[2], jet_colors[0])
-        tm.close()
-
-        # Test colormap functionality
-        bp = df.plot.box(colormap=cm.jet, return_type="dict")
-        _check_colors(bp, jet_colors[0], jet_colors[0], jet_colors[2], jet_colors[0])
-        tm.close()
+        _check_colors_box(
+            bp, jet_colors[0], jet_colors[0], jet_colors[2], jet_colors[0]
+        )
 
+    def test_boxplot_colors_single(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # string color is applied to all artists except fliers
         bp = df.plot.box(color="DodgerBlue", return_type="dict")
-        _check_colors(bp, "DodgerBlue", "DodgerBlue", "DodgerBlue", "DodgerBlue")
+        _check_colors_box(bp, "DodgerBlue", "DodgerBlue", "DodgerBlue", "DodgerBlue")
 
+    def test_boxplot_colors_tuple(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         # tuple is also applied to all artists except fliers
         bp = df.plot.box(color=(0, 1, 0), sym="#123456", return_type="dict")
-        _check_colors(bp, (0, 1, 0), (0, 1, 0), (0, 1, 0), (0, 1, 0), "#123456")
+        _check_colors_box(bp, (0, 1, 0), (0, 1, 0), (0, 1, 0), (0, 1, 0), "#123456")
 
+    def test_boxplot_colors_invalid(self):
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 5)))
         msg = re.escape(
             "color dict contains invalid key 'xxxx'. The key must be either "
             "['boxes', 'whiskers', 'medians', 'caps']"
@@ -609,39 +594,46 @@ class TestDataFrameColor(TestPlotBase):
 
     def test_default_color_cycle(self):
         import cycler
-        import matplotlib.pyplot as plt
 
         colors = list("rgbk")
         plt.rcParams["axes.prop_cycle"] = cycler.cycler("color", colors)
 
-        df = DataFrame(np.random.randn(5, 3))
+        df = DataFrame(np.random.default_rng(2).standard_normal((5, 3)))
         ax = df.plot()
 
-        expected = self._unpack_cycler(plt.rcParams)[:3]
-        self._check_colors(ax.get_lines(), linecolors=expected)
+        expected = _unpack_cycler(plt.rcParams)[:3]
+        _check_colors(ax.get_lines(), linecolors=expected)
 
     def test_no_color_bar(self):
-        df = self.hexbin_df
+        df = DataFrame(
+            {
+                "A": np.random.default_rng(2).uniform(size=20),
+                "B": np.random.default_rng(2).uniform(size=20),
+                "C": np.arange(20) + np.random.default_rng(2).uniform(size=20),
+            }
+        )
         ax = df.plot.hexbin(x="A", y="B", colorbar=None)
         assert ax.collections[0].colorbar is None
 
     def test_mixing_cmap_and_colormap_raises(self):
-        df = self.hexbin_df
+        df = DataFrame(
+            {
+                "A": np.random.default_rng(2).uniform(size=20),
+                "B": np.random.default_rng(2).uniform(size=20),
+                "C": np.arange(20) + np.random.default_rng(2).uniform(size=20),
+            }
+        )
         msg = "Only specify one of `cmap` and `colormap`"
         with pytest.raises(TypeError, match=msg):
             df.plot.hexbin(x="A", y="B", cmap="YlGn", colormap="BuGn")
 
     def test_passed_bar_colors(self):
-        import matplotlib as mpl
-
         color_tuples = [(0.9, 0, 0, 1), (0, 0.9, 0, 1), (0, 0, 0.9, 1)]
         colormap = mpl.colors.ListedColormap(color_tuples)
         barplot = DataFrame([[1, 2, 3]]).plot(kind="bar", cmap=colormap)
         assert color_tuples == [c.get_facecolor() for c in barplot.patches]
 
     def test_rcParams_bar_colors(self):
-        import matplotlib as mpl
-
         color_tuples = [(0.9, 0, 0, 1), (0, 0.9, 0, 1), (0, 0, 0.9, 1)]
         with mpl.rc_context(rc={"axes.prop_cycle": mpl.cycler("color", color_tuples)}):
             barplot = DataFrame([[1, 2, 3]]).plot(kind="bar")
@@ -654,41 +646,25 @@ class TestDataFrameColor(TestPlotBase):
         df1 = DataFrame({"a": [2, 4, 6]})
         df_concat = pd.concat([df, df1], axis=1)
         result = df_concat.plot()
-        for legend, line in zip(result.get_legend().legendHandles, result.lines):
+        legend = result.get_legend()
+        if Version(mpl.__version__) < Version("3.7"):
+            handles = legend.legendHandles
+        else:
+            handles = legend.legend_handles
+        for legend, line in zip(handles, result.lines):
             assert legend.get_color() == line.get_color()
 
     def test_invalid_colormap(self):
-        df = DataFrame(np.random.randn(3, 2), columns=["A", "B"])
-        msg = (
-            "'invalid_colormap' is not a valid value for name; supported values are "
-            "'Accent', 'Accent_r', 'Blues', 'Blues_r', 'BrBG', 'BrBG_r', 'BuGn', "
-            "'BuGn_r', 'BuPu', 'BuPu_r', 'CMRmap', 'CMRmap_r', 'Dark2', 'Dark2_r', "
-            "'GnBu', 'GnBu_r', 'Greens', 'Greens_r', 'Greys', 'Greys_r', 'OrRd', "
-            "'OrRd_r', 'Oranges', 'Oranges_r', 'PRGn', 'PRGn_r', 'Paired', "
-            "'Paired_r', 'Pastel1', 'Pastel1_r', 'Pastel2', 'Pastel2_r', 'PiYG', "
-            "'PiYG_r', 'PuBu', 'PuBuGn', 'PuBuGn_r', 'PuBu_r', 'PuOr', 'PuOr_r', "
-            "'PuRd', 'PuRd_r', 'Purples', 'Purples_r', 'RdBu', 'RdBu_r', 'RdGy', "
-            "'RdGy_r', 'RdPu', 'RdPu_r', 'RdYlBu', 'RdYlBu_r', 'RdYlGn', "
-            "'RdYlGn_r', 'Reds', 'Reds_r', 'Set1', 'Set1_r', 'Set2', 'Set2_r', "
-            "'Set3', 'Set3_r', 'Spectral', 'Spectral_r', 'Wistia', 'Wistia_r', "
-            "'YlGn', 'YlGnBu', 'YlGnBu_r', 'YlGn_r', 'YlOrBr', 'YlOrBr_r', "
-            "'YlOrRd', 'YlOrRd_r', 'afmhot', 'afmhot_r', 'autumn', 'autumn_r', "
-            "'binary', 'binary_r', 'bone', 'bone_r', 'brg', 'brg_r', 'bwr', "
-            "'bwr_r', 'cividis', 'cividis_r', 'cool', 'cool_r', 'coolwarm', "
-            "'coolwarm_r', 'copper', 'copper_r', 'cubehelix', 'cubehelix_r', "
-            "'flag', 'flag_r', 'gist_earth', 'gist_earth_r', 'gist_gray', "
-            "'gist_gray_r', 'gist_heat', 'gist_heat_r', 'gist_ncar', "
-            "'gist_ncar_r', 'gist_rainbow', 'gist_rainbow_r', 'gist_stern', "
-            "'gist_stern_r', 'gist_yarg', 'gist_yarg_r', 'gnuplot', 'gnuplot2', "
-            "'gnuplot2_r', 'gnuplot_r', 'gray', 'gray_r', 'hot', 'hot_r', 'hsv', "
-            "'hsv_r', 'inferno', 'inferno_r', 'jet', 'jet_r', 'magma', 'magma_r', "
-            "'nipy_spectral', 'nipy_spectral_r', 'ocean', 'ocean_r', 'pink', "
-            "'pink_r', 'plasma', 'plasma_r', 'prism', 'prism_r', 'rainbow', "
-            "'rainbow_r', 'seismic', 'seismic_r', 'spring', 'spring_r', 'summer', "
-            "'summer_r', 'tab10', 'tab10_r', 'tab20', 'tab20_r', 'tab20b', "
-            "'tab20b_r', 'tab20c', 'tab20c_r', 'terrain', 'terrain_r', 'turbo', "
-            "'turbo_r', 'twilight', 'twilight_r', 'twilight_shifted', "
-            "'twilight_shifted_r', 'viridis', 'viridis_r', 'winter', 'winter_r'"
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((3, 2)), columns=["A", "B"]
         )
-        with pytest.raises(ValueError, match=msg):
+        msg = "(is not a valid value)|(is not a known colormap)"
+        with pytest.raises((ValueError, KeyError), match=msg):
             df.plot(colormap="invalid_colormap")
+
+    def test_dataframe_none_color(self):
+        # GH51953
+        df = DataFrame([[1, 2, 3]])
+        ax = df.plot(color=None)
+        expected = _unpack_cycler(mpl.pyplot.rcParams)[:3]
+        _check_colors(ax.get_lines(), linecolors=expected)
